@@ -6,5 +6,7 @@ import sys
 def install_command():
     """Install Cairo package with the given tag."""
     print("🗄  Installing Cairo")
-    subprocess.check_call([sys.executable, "-m", "pip", "install", "cairo-lang"])
+    subprocess.check_call(
+        [sys.executable, "-m", "pip", "install", "cairo-lang", "starknet-devnet"]
+    )
     print("✨  Cairo successfully installed!")
